# Copyright 1999-2010 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI="3"

inherit autotools

DESCRIPTION="An enhanced multi-threaded syslogd with database support and more."
HOMEPAGE="http://www.rsyslog.com/"
SRC_URI="http://www.rsyslog.com/files/download/${PN}/${P}.tar.gz"

LICENSE="GPL-3 LGPL-3"
KEYWORDS="~amd64 ~arm ~hppa ~sparc ~x86"
SLOT="0"
IUSE="relp gnutls kerberos dbi logrotate mysql postgres oracle snmp zlib debug static-libs"

DEPEND="net-libs/libnet
	kerberos? ( virtual/krb5 )
	dbi? ( dev-db/libdbi )
	gnutls? ( net-libs/gnutls )
	mysql? ( virtual/mysql )
	postgres? ( virtual/postgresql-base )
	oracle? ( dev-db/oracle-instantclient-basic )
	relp? ( >=dev-libs/librelp-0.1.1 )
	snmp? ( net-analyzer/net-snmp )
	zlib? ( sys-libs/zlib )
	logrotate? ( app-admin/logrotate )"
RDEPEND="${DEPEND}"
PROVIDE="virtual/logger"

BRANCH="5-stable"

# need access to certain device nodes
RESTRICT="test"

src_configure() {
	# Maintainer notes:
	# * rfc3195 needs a library and development of that library
	#   is suspended, so we disable it
	#
	# About the java GUI:
	# The maintainer says there is no real installation support
	# for the java GUI, so we disable it for now.
	econf \
		--disable-gui \
		--disable-rfc3195 \
		--enable-largefile \
		--enable-imdiag \
		--enable-imfile \
		--enable-imtemplate \
		--enable-mail \
		--enable-omprog \
		--enable-omstdout \
		--enable-omudpspoof \
		--enable-omtemplate \
		$(use_enable zlib) \
		$(use_enable mysql) \
		$(use_enable dbi libdbi) \
		$(use_enable postgres pgsql) \
		$(use_enable oracle oracle) \
		$(use_enable gnutls) \
		$(use_enable kerberos gssapi-krb5) \
		$(use_enable relp) \
		$(use_enable snmp) \
		$(use_enable debug) \
		$(use_enable debug rtinst) \
		$(use_enable debug diagtools) \
		$(use_enable debug memcheck) \
		$(use_enable debug valgrind) \
		$(use_enable static-libs static)
}

src_install() {
	emake DESTDIR="${D}" install || die "emake install failed"

	dodoc AUTHORS ChangeLog doc/rsyslog-example.conf || die
	dohtml -r doc/*

	insinto /etc
	newins "${FILESDIR}/${BRANCH}/rsyslog-gentoo.conf" rsyslog.conf

	newconfd "${FILESDIR}/${BRANCH}/rsyslog.conf" rsyslog
	newinitd "${FILESDIR}/${BRANCH}/rsyslog.init" rsyslog

	insinto /etc/logrotate.d/
	newins "${FILESDIR}/${BRANCH}/rsyslog.logrotate" rsyslog

	if use mysql; then
		insinto /usr/share/doc/${PF}/scripts/mysql
		doins plugins/ommysql/{createDB.sql,contrib/delete_mysql}
	fi

	if use postgres; then
		insinto /usr/share/doc/${PF}/scripts/pgsql
		doins plugins/ompgsql/createDB.sql
	fi
}

pkg_postinst() {
	echo
	if use mysql || use postgres; then
		einfo "SQL scripts to create the tables for MySQL or PostgreSQL have been installed to:"
		einfo "  /usr/share/doc/${PF}/scripts"
		echo
	fi

	if use gnutls; then
		einfo "To encrypt syslog traffic with TLS (SSL), read:"
		einfo "  http://www.rsyslog.com/doc/rsyslog_tls.html"
		echo
	fi
}
